@@ -11,10 +11,10 @@ more details.
 
 You should have received a copy of the GNU Lesser General Public License
 along with this library; if not, write to the Free Software Foundation, Inc.,
-59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2007 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2010 Live Networks, Inc.  All rights reserved.
 // A server demultiplexer for a MPEG 1 or 2 Program Stream
 // Implementation
 
@@ -142,7 +142,7 @@ static float MPEG1or2ProgramStreamFileDuration(UsageEnvironment& env,
     if (!getMPEG1or2TimeCode(dataSource, *baseDemux, True, firstTimeCode)) break;
 
     // Then, read the last time code from the file.
-    // (Before doing this, flush the demux's input buffers, 
+    // (Before doing this, flush the demux's input buffers,
     //  and seek towards the end of the file, for efficiency.)
     baseDemux->flushInput();
     unsigned const startByteFromEnd = 100000;
@@ -163,6 +163,8 @@ static float MPEG1or2ProgramStreamFileDuration(UsageEnvironment& env,
   return duration;
 }
 
+#define DUMMY_SINK_BUFFER_SIZE (6+65535) /* large enough for a PES packet */
+
 class DummySink: public MediaSink {
 public:
   DummySink(MPEG1or2Demux& demux, Boolean returnFirstSeenCode);
@@ -184,7 +186,7 @@ private:
 private:
   MPEG1or2Demux& fOurDemux;
   Boolean fReturnFirstSeenCode;
-  unsigned char fBuf[10000];
+  unsigned char fBuf[DUMMY_SINK_BUFFER_SIZE];
 };
 
 static void afterPlayingDummySink(DummySink* sink); // forward
@@ -201,7 +203,7 @@ static Boolean getMPEG1or2TimeCode(FramedSource* dataSource,
   sink.startPlaying(*dataSource,
 		    (MediaSink::afterPlayingFunc*)afterPlayingDummySink, &sink);
   env.taskScheduler().doEventLoop(&sink.watchVariable);
-  
+
   timeCode = computeSCRTimeCode(parentDemux.lastSeenSCR());
   return parentDemux.lastSeenSCR().isValid;
 }
@@ -246,7 +248,7 @@ void DummySink::afterGettingFrame1() {
 }
 
 static void afterPlayingDummySink(DummySink* sink) {
-  // Return from the "doEventLoop()" call: 
+  // Return from the "doEventLoop()" call:
   sink->watchVariable = ~0;
 }
 
